==> component-huawei-push-2.0.8.2-20210114.074416-10-sources.jar: com/huawei/push/javasdk/message/Message.java <==
package com.huawei.push.javasdk.message;

import com.alibaba.fastjson.annotation.JSONField;
import com.google.common.base.Strings;
import com.google.common.primitives.Booleans;
import com.huawei.push.javasdk.util.CollectionUtils;
import com.huawei.push.javasdk.util.ValidatorUtils;
import org.apache.commons.lang3.StringUtils;

import java.util.ArrayList;
import java.util.List;

public class Message {

    @JSONField(name = "data")
    private String data;

    @JSONField(name = "notification")
    private Notification notification;

    @JSONField(name = "android")
    private AndroidConfig androidConfig;

    @JSONField(name = "token")
    private List<String> token = new ArrayList<>();

    @JSONField(name = "topic")
    private String topic;

    @JSONField(name = "condition")
    private String condition;

    private Message(Builder builder) {
        this.data = builder.data;
        this.notification = builder.notification;
        this.androidConfig = builder.androidConfig;

        if (!CollectionUtils.isEmpty(builder.token)) {
            this.token.addAll(builder.token);
        } else {
            this.token = null;
        }

        this.topic = builder.topic;
        this.condition = builder.condition;

        /** check after message is created */
        check();
    }

    /**
     * check message's parameters
     */
    public void check() {

        int count = Booleans.countTrue(
                !CollectionUtils.isEmpty(this.token),
                !Strings.isNullOrEmpty(this.topic),
                !Strings.isNullOrEmpty(this.condition)
        );

        ValidatorUtils.checkArgument(count == 1, "Exactly one of token, topic or condition must be specified");

        boolean isEmptyData = StringUtils.isEmpty(data);

        if (null != this.androidConfig) {
            this.androidConfig.check(this.notification);
        }
    }

    /**
     * getter
     */
    public String getData() {
        return data;
    }

    public Notification getNotification() {
        return notification;
    }

    public AndroidConfig getAndroidConfig() {
        return androidConfig;
    }

    public List<String> getToken() {
        return token;
    }

    public String getTopic() {
        return topic;
    }

    public String getCondition() {
        return condition;
    }

    /**
     * builder
     * @return
     */
    public static Builder builder() {
        return new Builder();
    }

    /**
     * push message builder
     */
    public static class Builder {
        private String data;
        private Notification notification;
        private AndroidConfig androidConfig;
        private List<String> token = new ArrayList<>();
        private String topic;
        private String condition;

        private Builder() {}

        public Builder setData(String data) {
            this.data = data;
            return this;
        }

        public Builder setNotification(Notification notification) {
            this.notification = notification;
            return this;
        }

        public Builder setAndroidConfig(AndroidConfig androidConfig) {
            this.androidConfig = androidConfig;
            return this;
        }

        public Builder addToken(String token) {
            this.token.add(token);
            return this;
        }

        public Builder addAllToken(List<String> tokens) {
            this.token.addAll(tokens);
            return this;
        }

        public Builder setTopic(String topic) {
            this.topic = topic;
            return this;
        }

        public Builder setCondition(String condition) {
            this.condition = condition;
            return this;
        }

        public Message build() {
            return new Message(this);
        }
    }
}

==> component-huawei-push-2.1.6-20210726.080722-5-sources.jar: com/huawei/push/javasdk/message/Message.java <==
package com.huawei.push.javasdk.message;

import com.fasterxml.jackson.annotation.JsonProperty;
import com.google.common.base.Strings;
import com.google.common.primitives.Booleans;
import com.huawei.push.javasdk.util.CollectionUtils;
import com.huawei.push.javasdk.util.ValidatorUtils;
import org.apache.commons.lang3.StringUtils;

import java.util.ArrayList;
import java.util.List;

public class Message {

    @JsonProperty( "data")
    private String data;

    @JsonProperty("notification")
    private Notification notification;

    @JsonProperty("android")
    private AndroidConfig androidConfig;

    @JsonProperty("token")
    private List<String> token = new ArrayList<>();

    @JsonProperty("topic")
    private String topic;

    @JsonProperty("condition")
    private String condition;

    private Message(Builder builder) {
        this.data = builder.data;
        this.notification = builder.notification;
        this.androidConfig = builder.androidConfig;

        if (!CollectionUtils.isEmpty(builder.token)) {
            this.token.addAll(builder.token);
        } else {
            this.token = null;
        }

        this.topic = builder.topic;
        this.condition = builder.condition;

        /** check after message is created */
        check();
    }

    /**
     * check message's parameters
     */
    public void check() {

        int count = Booleans.countTrue(
                !CollectionUtils.isEmpty(this.token),
                !Strings.isNullOrEmpty(this.topic),
                !Strings.isNullOrEmpty(this.condition)
        );

        ValidatorUtils.checkArgument(count == 1, "Exactly one of token, topic or condition must be specified");

        boolean isEmptyData = StringUtils.isEmpty(data);

        if (null != this.androidConfig) {
            this.androidConfig.check(this.notification);
        }
    }

    /**
     * getter
     */
    public String getData() {
        return data;
    }

    public Notification getNotification() {
        return notification;
    }

    public AndroidConfig getAndroidConfig() {
        return androidConfig;
    }

    public List<String> getToken() {
        return token;
    }

    public String getTopic() {
        return topic;
    }

    public String getCondition() {
        return condition;
    }

    /**
     * builder
     * @return
     */
    public static Builder builder() {
        return new Builder();
    }

    /**
     * push message builder
     */
    public static class Builder {
        private String data;
        private Notification notification;
        private AndroidConfig androidConfig;
        private List<String> token = new ArrayList<>();
        private String topic;
        private String condition;

        private Builder() {}

        public Builder setData(String data) {
            this.data = data;
            return this;
        }

        public Builder setNotification(Notification notification) {
            this.notification = notification;
            return this;
        }

        public Builder setAndroidConfig(AndroidConfig androidConfig) {
            this.androidConfig = androidConfig;
            return this;
        }

        public Builder addToken(String token) {
            this.token.add(token);
            return this;
        }

        public Builder addAllToken(List<String> tokens) {
            this.token.addAll(tokens);
            return this;
        }

        public Builder setTopic(String topic) {
            this.topic = topic;
            return this;
        }

        public Builder setCondition(String condition) {
            this.condition = condition;
            return this;
        }

        public Message build() {
            return new Message(this);
        }
    }
}
